@@ -1,6 +1,6 @@
 import json
 
-from rich.console import Console
+from rich.console import Console, OverflowMethod
 from rich.table import Table
 
 
@@ -32,6 +32,7 @@ class Printing:
             to_out += "\n"
         if to_out:
             console.print(to_out)
+
         to_out = ""
 
         if text["Regexes"]:
@@ -39,12 +40,12 @@ class Printing:
             table = Table(
                 show_header=True, header_style="bold #D7Afff", show_lines=True
             )
-            table.add_column("Matched Text")
-            table.add_column("Identified as")
-            table.add_column("Description")
+            table.add_column("Matched Text", overflow="fold")
+            table.add_column("Identified as", overflow="fold")
+            table.add_column("Description", overflow="fold")
             for i in text["Regexes"]:
-                matched = str(i["Matched"])
-                name = str(i["Regex Pattern"]["Name"])
+                matched = i["Matched"]
+                name = i["Regex Pattern"]["Name"]
                 description = self.get_crypto_links(name, matched)
                 if not description:
                     description = i["Regex Pattern"]["Description"]
@@ -54,6 +55,10 @@ class Printing:
                     description,
                 )
             console.print(to_out, table)
+        else:
+            console.print(
+                "[bold #D7Afff]Could not find anything of interest.[/bold #D7Afff]"
+            )
         """
         # This is commented out because there's too many possible hash idenfications
         # This is fixed by https://github.com/HashPals/Name-That-Hash/issues/89
@@ -85,7 +90,8 @@ class Printing:
             "Bitcoin Wallet": "https://www.blockchain.com/btc/address/",
             "YouTube Video ID": "https://www.youtube.com/watch?v=",
             "YouTube Channel ID": "https://www.youtube.com/channel/",
+            "Latitude & Longitude Coordinates": "https://www.google.com/maps/place/",
         }
         if text in explorers:
-            return "Click here to analyse in the browser " + explorers[text] + matched
+            return "Click here to analyse in the browser " + explorers[text] + matched.replace(" ", "")
         return None
